diff --git a/pgweb/util/contexts.py b/pgweb/util/contexts.py
index 43f6c3e..cc51f00 100644
--- a/pgweb/util/contexts.py
+++ b/pgweb/util/contexts.py
@@ -6,9 +6,7 @@ from django.conf import settings
 sitenav = {
     'about': [
         {'title': 'About', 'link': '/about/'},
-        {'title': 'Code of Conduct', 'link': '/about/policies/coc/', 'submenu': [
-            {'title': 'Committee', 'link': '/about/policies/coc_committee/'}
-        ]},
+        {'title': 'Policies', 'link': '/about/policies/'},
         {'title': 'Feature Matrix', 'link': '/about/featurematrix/'},
         {'title': 'Donate', 'link': '/about/donate/'},
         {'title': 'History', 'link': '/docs/current/history.html'},
diff --git a/templates/pages/about/policies.html b/templates/pages/about/policies.html
new file mode 100644
index 0000000..681ecd4
--- /dev/null
+++ b/templates/pages/about/policies.html
@@ -0,0 +1,39 @@
+{%extends "base/page.html"%}
+{%block title%}Policies{%endblock%}
+{%block contents%}
+
+<h1>Policies <i class="fas fa-gavel"></i></h1>
+
+<p>Formal policies governing various aspects of the PostgreSQL Project can
+    be found here:</p>
+
+<h2>General Policies</h2>
+
+<ul>
+    <li><a href="/about/policies/twitter_policy/">@postgresql Twitter Account Policy</a></li>
+    <li><a href="/about/policies/archives/">Archives Policy</a></li>
+    <li><a href="/about/policies/coc/">Code of Conduct</a></li>
+    <li><a href="/about/policies/project_name/">Project Name</a></li>
+    <li><a href="/about/policies/trademark_policy/">Trademark Policy</a></li>
+    <li><a href="/support/versioning/">Versioning Policy</a></li>
+</ul>
+
+<h2>Approval Policies</h2>
+
+<ul>
+    <li><a href="/about/policies/news_events_approval/">News &amp; Events
+        Approval</a></li>
+    <li><a href="/about/policies/planet_postgresql/">Planet PostgreSQL</a></li>
+    <li><a href="/about/policies/services_hosting_approval/">Professional
+        Services &amp; Hosting Approval</a></li>
+    <li><a href="/about/policies/sponsoring/">Sponsoring</a></li>
+</ul>
+
+<h2>Community Recognition Guidelines</h2>
+
+<ul>
+    <li><a href="/community/recognition/#conferences">Conferences</a></li>
+    <li><a href="/community/recognition/#npos">Non-profit Organisations</a></li>
+</ul>
+
+{%endblock%}
\ No newline at end of file
diff --git a/templates/pages/about/policies/archives.html b/templates/pages/about/policies/archives.html
new file mode 100644
index 0000000..3a8fbd7
--- /dev/null
+++ b/templates/pages/about/policies/archives.html
@@ -0,0 +1,60 @@
+{%extends "base/page.html"%}
+{%block title%}Archives Policy{%endblock%}
+{%block contents%}
+
+<h1>Archives Policy <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: February 6, 2019</em></p>
+
+<p>The PostgreSQL <a href="/list/">mailing lists</a> are archived at
+    www.postgresql.org. This site is intended to provide an accurate
+    representation of the activity on the lists, and as such will not be
+    modified.</p>
+
+<h2>Why won't you remove my post?</h2>
+
+<p>There are a number of reasons why we will not remove or modify messages in
+    the archives:</p>
+
+<ul>
+    <li>We want the archives to accurately represent the history of our public
+        mailing lists.
+    </li>
+    <li>Messages posted to our mailing lists are archived by other organisations
+        outside of our control, as well as in every list subscriber's inbox.
+        Removing a message from our archives would only be the tip of the
+        iceberg.
+    </li>
+    <li>Due to the way the archives are stored and occasionally regenerated from
+        archived mailbox files, there is no way to permanently modify a message.
+    </li>
+    <li>We have limited volunteer resources to run the project (and no
+        non-volunteer resources) and would prefer to use those resources to
+        produce great database management software than to rewrite history.
+    </li>
+</ul>
+
+<h2>E-Mail Disclaimers and Licencing</h2>
+
+<p>Some companies or organization add footers to outgoing e-mail messages with
+    that group's e-mail policies, such as this simple example:</p>
+
+<blockquote>This e-mail is confidential and only for use by the intended
+    recipient.
+</blockquote>
+
+<p>These disclaimers are incompatible with sending messages to the PostgreSQL
+    mailing lists. When the mailing list is the "intended recipient", that
+    includes all of its current subscribers and the archives. These archives are
+    public, archived, and searchable; they cannot be made confidential.</p>
+
+<p>By choosing to send messages to a PostgreSQL mailing list, you are implicitly
+    granting your permission for that message to be archived in that fashion,
+    regardless of any e-mail disclaimer it might have. Additionally, source code
+    submissions to mailing lists such as pgsql-hackers are considered
+    submissions to the PostgreSQL project, falling under the project's
+    <a href="/about/licence/">PostgreSQL licence</a>. Please make sure you have
+    permission to share information with these lists before sending your
+    message.</p>
+
+{%endblock%}
diff --git a/templates/pages/about/policies/news_events_approval.html b/templates/pages/about/policies/news_events_approval.html
new file mode 100644
index 0000000..cb7b422
--- /dev/null
+++ b/templates/pages/about/policies/news_events_approval.html
@@ -0,0 +1,244 @@
+{%extends "base/page.html"%}
+{%block title%}News and Events Approval Policy{%endblock%}
+{%block contents%}
+
+<h1>News and Events Approval Policy <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: March 29, 2018</em></p>
+
+<h2>Policies for Approving News &amp; Events &amp; pgsql-announce</h2>
+
+<h3>General Rules</h3>
+
+<p>The www.postgresql.org home page contains News and Events listings which are
+    maintained entirely for the benefit of the PostgreSQL community. As this
+    space would be quite valuable (up to $400 per listing) if commercially
+    available, our admins have unlimited authority to be restrictive about what
+    they allow on the home page.</p>
+
+<p>All News and Events (including Training Events) to be approved must include
+    the following information:</p>
+
+<ul>
+    <li>Accurate contact information</li>
+    <li>A descriptive title which distinguishes the item from similar items</li>
+    <li>A 10 to 25 word summary of the item which provides enough information
+        to clearly let RSS readers know if they want more information.
+    </li>
+    <li>A description of the news or event which clearly explains what it is
+        and how it relates to PostgreSQL.
+    </li>
+</ul>
+
+<p>Other General Rules include:</p>
+
+<ul>
+    <li>All items must relate to PostgreSQL in some direct and obvious way.</li>
+    <li>Link-only events or news will never be acceptable.</li>
+    <li>The WWW admin group of the PostgreSQL project may permanently ban any
+        organization which is the cause of substantiated complaints about
+        accuracy, ethics or legality from members of our community.
+    </li>
+    <li>The WWW team makes no promises about timely approval of announcements.
+        If publication on a specific day is critical to you, you will need to
+        contact the pgsql-www mailing list or a core team member prior to the
+        submission.
+    </li>
+    <li>Companies listed on the sponsors page may be granted an exception to
+        any of the limitations on news and events, such as allowed posting
+        frequency, at the discretion of the web team.
+    </li>
+    <li>The WWW team reserves the right to partially or entirely rewrite News
+        or Events postings to improve clarity.
+    </li>
+    <li>Starting at midnight UTC on the day of a PostgreSQL release, including
+        any beta or release candidate (RC), no new announcement request will be
+        approved until after midnight UTC 72 hours later. For example, if a new
+        version of PostgreSQL is released on 2018-02-08, then no other
+        announcements will be approved between 2018-02-08 0:00 UTC and
+        2018-02-11 0:00 UTC. Any announcements submitted *during* this time
+        should have their timestamp updated once they are approved, so they
+        don't end up looking like old once they do post.
+    </li>
+</ul>
+
+<p>In general, the postgresql.org home page is run exclusively for the benefit
+    of the not-for-profit member-owned PostgreSQL community. It is not an
+    advertising venue, and site admins are entitled to reject any notice which
+    they feel is inconsistent with the community's needs for any reason, or for
+    no reason.</p>
+
+<h2>Approving News and Announcements</h2>
+
+<p>All News policy below is considered to apply equally to the home page and
+    pgsql-announce, except that pgsql-announce also carries PWN.</p>
+
+<h3>PostgreSQL Core News</h3>
+
+<p>All items will be approved unless inaccurate. The following types of news are
+    generally appropriate for the home page:</p>
+
+<ul>
+    <li>All releases, major, minor and beta</li>
+    <li>Development schedule milestones</li>
+    <li>New certifications, awards & benchmarks</li>
+    <li>Core team and committer changes</li>
+    <li>Security issues</li>
+    <li>Calls for assistance/participation</li>
+    <li>Major changes to infrastructure, web, or legal structure of PostgreSQL
+    </li>
+    <li>Major new advocacy efforts</li>
+</ul>
+
+<h3>PostgreSQL "Family" News</h3>
+
+<p>This includes news about PostgreSQL add-on projects & drivers, open source
+    projects which are primarily based on PostgreSQL, and news about PostgreSQL
+    regional and user groups.</p>
+
+<p>Any of the following items will be approved, regardless of frequency:</p>
+
+<ul>
+    <li>Any release or initial beta of a major release</li>
+    <li>Creation of any new user group, regional group, or web site</li>
+    <li>Critical security patch announcements</li>
+    <li>Substantial new articles or documentation</li>
+    <li>Infrequent calls for assistance/participation</li>
+</ul>
+
+<p>Other types of news, such as changes in leadership, will not be approved.</p>
+
+<h3>Proprietary & External OSS Project News</h3>
+<p>This includes all news from companies whose products contain, support or are
+    based on PostgreSQL, and OSS projects which support PostgreSQL as one of
+    several database options.</p>
+
+<p>The following types of news will be approved:</p>
+
+<ul>
+    <li>Brand new products/projects/services which support or center around
+        PostgreSQL
+    </li>
+    <li>Newly released books about PostgreSQL or with substantial (20% or more)
+        PostgreSQL content.
+    </li>
+    <li>First support of PostgreSQL in existing products</li>
+    <li>Major version releases (not more than once per quarter)</li>
+    <li>Critical security updates, if thought to affect many PostgreSQL
+        community members
+    </li>
+</ul>
+
+<p>Other types of announcements, including minor releases, pricing changes,
+    leadership changes, 3rd-party news coverage, partnerships, and mergers &
+    acquisitions will be rejected.</p>
+
+<p>In addition, commercial entities who are not financial, in-kind or code
+    contributors to the PostgreSQL project will be restricted to one news item
+    of any kind per six-month period.</p>
+
+<h3>Procedure for Approving pgsql-announce</h3>
+
+<p>Since pgsql-announce goes to over 30,000 addresses, we are cautious in what
+    we approve to that list. In some cases, this may result in a delay of up to
+    several days in approving announcements.</p>
+
+<ol><li>Check if it's spam and reject spam.</li>
+    <li>Check if there is anything else in the 'To' or 'CC' list besides
+        -announce; if so, reject and ask for re-submission.
+    </li>
+    <li>Read the announcement</li>
+    <li>Consider if the announcement meets this policy and is appropriate for
+        announcement
+        <ul>
+            <li>if necessary, check on pgsql-www list</li>
+        </ul>
+    </li>
+    <li>Approve or Reject</li>
+</ol>
+<p>In any case where an approver has doubts about whether to approve an
+    announcement or not, they should err on the side of caution.</p>
+
+<p>Please note that PostgreSQL major/minor release posts should be handled by
+    the release team, not by the pgsql-announce moderators.</p>
+
+<h2>Approving Events and Event-Related News (excluding training)</h2>
+
+<p>Events must have significant PostgreSQL-related content in order to be
+    listed.</p>
+
+<h3>PostgreSQL Conferences & Events</h3>
+<p>Any semi-annual or less frequent non-training event which is primarily about
+    PostgreSQL or for PostgreSQL users will be entitled to be listed.
+    Additionally, conferences which are primarily or entirely about PostgreSQL
+    will be entitled to post news items at the following milestones, if they are
+    each a week or more apart:</p>
+
+<ul>
+    <li>Call for Papers</li>
+    <li>Schedule Posting,</li>
+    <li>Registration Opening,</li>
+    <li>Registration Closing,</li>
+    <li>Wrap-up.</li>
+</ul>
+
+<p>Routine monthly PostgreSQL User Group meetings will not be listed. First
+    meetings of a new PUG can be listed, as well as infrequent major special
+    events likely to be of interest outside of the PUG's normal area.</p>
+
+<h3>Open Source & Database Conferences & Events</h3>
+
+<p>Open source conferences, and database conferences, which are not primarily
+    about PostgreSQL but have significant PostgreSQL content, such as several
+    sessions and a booth, may be listed in the Events. Additionally, the Call
+    For Papers for these events may be accepted as News.</p>
+
+<p>More routine events, such as monthly local meetings or mini-conferences, will
+    not be listed. Conferences must have significant PostgreSQL content to be
+    worth listing, with decisions on relative significance to be made by the WWW
+    team.</p>
+
+<h2>Training Events</h2>
+
+<p>PostgreSQL Training may be listed from any company, under the following
+    conditions:</p>
+
+<ul>
+    <li>Each listing must include:
+        <ul>
+            <li>Specific locations and dates for that specific training</li>
+            <li>Link to online training registration</li>
+            <li>One or more sentence description of the contents of that
+                specific training
+            </li>
+        </ul>
+    </li>
+</ul>
+
+<p>All descriptive text should be purely informative and not include strong
+    marketing copy or special offers unrelated to the training. The vendors
+    website should list PostgreSQL training information, including an online
+    schedule of upcoming trainings.</p>
+
+<p>In the event that any training company submits more than 4 training events to
+    be held in any given quarter, site admins may (at their discretion) deny
+    posting events to that company.</p>
+
+<h2>Rejection Notices</h2>
+
+<p>In cases where the submitter appears to have gone to some effort to submit a
+    relevant news item or event, but doesn't understand our policies, we should
+    send them a rejection e-mail linking to this page and explaining what was
+    wrong with their submission. This certainly goes for any of the major
+    project sponsors.</p>
+
+<p>If the submission looks like a 30-second cut-and-paste job, or something else
+    sloppy and quick, or is a submission by someone who has had multiple
+    submissions rejected in the past for the same reason, don't bother sending a
+    response. We get too much spam for that.</p>
+
+<p>Any company which has had submissions repeatedly rejected for the same
+    reasons, and does not correct their errors when notified, risks having their
+    community account suspended and their ability to submit news and events
+    blocked.</p>
+{%endblock%}
diff --git a/templates/pages/about/policies/planet_postgresql.html b/templates/pages/about/policies/planet_postgresql.html
new file mode 100644
index 0000000..b9436d4
--- /dev/null
+++ b/templates/pages/about/policies/planet_postgresql.html
@@ -0,0 +1,144 @@
+{%extends "base/page.html"%}
+{%block title%}Planet PostgreSQL{%endblock%}
+{%block contents%}
+
+<h1>Planet PostgreSQL <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: October 12, 2016</em></p>
+
+<p><a href="https://planet.postgresql.org/">Planet PostgreSQL</a> is a blog
+    aggregation service run by the PostgreSQL community. In addition to the main
+    Planet site, entries are published ("syndicated") to the <a
+            href="https://www.postgresql.org/">www.postgresql.org</a> site as
+    well.</p>
+
+<h2>Planet PostgreSQL Policy</h2>
+
+<p>The following simple rules cover the blogs being listed on Planet
+    PostgreSQL:</p>
+
+<ul>
+    <li>Blogs should be submitted by a community account in the name of the blog
+        author.
+    </li>
+    <li>All blogs should be about PostgreSQL or closely related technologies. If
+        you want to blog about other things as well, please put your PostgreSQL
+        specific posts in a separate category/tag/label, and use the feed for
+        this category only for Planet PostgreSQL.
+    </li>
+    <li>All topics related to PostgreSQL are of course appreciated - both
+        technical and non-technical.
+    </li>
+    <li>All posts should be in English. If you want to blog in other languages,
+        please put your PostgreSQL specific posts in a separate
+        category/tag/label, and use the feed for this category only for Planet
+        PostgreSQL.
+    </li>
+    <li>All blogs should be identified by the posters name. A nickname is
+        allowed to be used in combination with this, but blogs without names are
+        not allowed.
+    </li>
+    <li>Avoid inflammatory comments in syndicated posts. Personal attacks are
+        not permitted.
+    </li>
+    <li>Publishing of advertising in the syndicated part of your blog is not
+        permitted.
+    </li>
+</ul>
+
+<p>Violating these rules will cause your blog to be removed from Planet
+    PostgreSQL.</p>
+
+<h3>Approval of Blogs</h3>
+
+<p>Planet PostgreSQL volunteer moderators approve your blog once you submit the
+    syndication request. Note the following points:</p>
+
+<ul>
+    <li>The blog must have at least one article before approval, so that the
+        moderators can make a decision based on the initial contents. Empty
+        blogs are not approved.
+    </li>
+    <li>Moderators are not allowed to approve blogs owned by other employees of
+        their own employer.
+    </li>
+</ul>
+
+<h2>Planet PostgreSQL FAQ</h2>
+
+<h3>How can I remove a bad entry from the feed?</h3>
+<p>It's possible to login to the administration interface and hide an individual
+    entry. If you realize you've made a mistake and done something like
+    accidentally posting incorrectly tagged content, removing it on your own is
+    recommended.</p>
+
+<h3>What are the right URLs to use for a labeled feed from <a
+        href="http://www.blogger.com/">blogger.com</a>?</h3>
+<p>Assuming your blog is named "blogname" and you've tagged a subset of your
+    posts with the "postgresql" label, the correct URLs to input to the Planet
+    code are:</p>
+
+<ul>
+    <li>Feedurl: <a href="http://blogname.blogspot.com/search/label/postgresql">http://blogname.blogspot.com/search/label/postgresql</a>
+    </li>
+    <li>Blogurl: <a
+            href="http://blogname.blogspot.com/feeds/posts/default/-/postgresql">http://blogname.blogspot.com/feeds/posts/default/-/postgresql</a>
+    </li>
+</ul>
+
+<p>You can confirm those URLs display a suitable copy of your feed via a web
+    browser before submitting them.</p>
+
+<h3>Are commercial posts allowed?</h3>
+<p>Informative entries that mention proprietary products are normally
+    permissible, as long as the main entry is relevant to the PostgreSQL
+    community. But the policy specifically prohibits publication of advertising
+    in the portion of a blog that is syndicated to the Planet feed. It's
+    recommended that blogs that may contain ads tag them appropriately, to
+    provide a feed to the Planet without those entries included.</p>
+
+<h3>What constitutes an advertisement?</h3>
+<p>The primary test here is whether the information provided would be of some
+    use even to people who have no interest in the commercial product mentioned.
+    Consider what your entry would look like if all references to the product
+    were removed. If there's no useful PostgreSQL content left after doing that,
+    that post is an ad.</p>
+
+<p>You can find a blog entry giving a more detailed opinion from one of the
+    moderators about this subject at <a
+            href="https://blog.2ndquadrant.com/planetary_alignment/">Planetary
+        alignment</a>. That commentary is not part of the official policy.</p>
+
+<h3>Can I offer free or discounted products to people?</h3>
+<p>Not as your only post content. An article that otherwise meets the standards
+    here, by providing useful information to readers with no interest in the
+    commercial product mentioned, might also include some commercial offer like
+    a free product in them. But promotions like product giveaways or providing a
+    discount to blog readers are not acceptable on their own. You might consider
+    the offer itself informative, but the moderators of the Planet feed will
+    usually judge it to be advertisement. Blog entries offering to give away
+    something for free or at a reduced cost are very likely to be flagged as a
+    violation of policy.</p>
+
+<h3>What happens to blogs that violate the site policies?</h3>
+<p>A first violation of the advertising policy will result in the blog entry
+    with the ad being removed, and a warning e-mail sent to the listed owner of
+    the blog.</p>
+
+<p>A second violation will resulting in the blog being removed from the Planet
+    PostgreSQL feed. After a two month suspension period, the blog owner can
+    submit their blog address--or a new feed URL better tagged to filter out
+    advertisements--for reconsideration.</p>
+
+<p>A third violation in any year will result in a full 12 month suspension of
+    the blog from Planet PostgreSQL.</p>
+
+<h3>Who makes the moderation decisions about the Planet content allowed?</h3>
+<p>Site maintenance and moderation duty is done by a small team of volunteer
+    moderators, primarily made up of <a
+            href="https://www.postgresql.org/community/contributors/">PostgreSQL
+        contributors</a> from various companies who are familiar with the
+    policies of the PostgreSQL community.</p>
+
+
+{%endblock%}
diff --git a/templates/pages/about/policies/project_name.html b/templates/pages/about/policies/project_name.html
new file mode 100644
index 0000000..b503518
--- /dev/null
+++ b/templates/pages/about/policies/project_name.html
@@ -0,0 +1,27 @@
+{%extends "base/page.html"%}
+{%block title%}Project Name{%endblock%}
+{%block contents%}
+
+<h1>Project Name <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: July 5, 2018</em></p>
+
+<h2>PostgreSQL versus Postgres</h2>
+
+<p>The name Postgres is an accepted alias for the PostgreSQL project. However it
+    is an alias or nickname and is not the official name of the project. Per
+    Dave Page, PostgreSQL Core Team:</p>
+
+<blockquote>Following recent discussions on a name change for the project, it has become
+    clear that consensus within the community will never be reached. In light of
+    this, the core team have discussed the matter in depth and decided that the
+    project shall continue to use the name PostgreSQL, but accept the use of
+    Postgres as an alias.<br /><br />
+
+    Regards, Dave</blockquote>
+
+<p>Ref: <a
+        href="https://www.postgresql.org/message-id/473D7617.6070900@postgresql.org">Project
+    name - statement from the core team</a>.</p>
+
+{%endblock%}
diff --git a/templates/pages/about/policies/services_hosting_approval.html b/templates/pages/about/policies/services_hosting_approval.html
new file mode 100644
index 0000000..bcb5cf2
--- /dev/null
+++ b/templates/pages/about/policies/services_hosting_approval.html
@@ -0,0 +1,125 @@
+{%extends "base/page.html"%}
+{%block title%}Professional Services and Hosting Approval Policy{%endblock%}
+{%block contents%}
+
+<h1>Professional Services and Hosting Approval Policy <i class="fas fa-gavel">
+    </i></h1>
+
+<p><em>Last updated: May 19, 2012</em></p>
+
+<h2>Policies for Approving Professional Services and Hosting Services</h2>
+
+<h3>General Rules</h3>
+
+<p>The www.postgresql.org home page contains Professional Services and Hosting
+    (in general, Services) listings which are maintained entirely for the
+    benefit of the PostgreSQL community. As this space would be quite valuable
+    if commercially available, our admins have the authority to be restrictive
+    about what they allow on the home page.</p>
+
+<p>All Services to be approved must include the following information:</p>
+
+<ul>
+    <li>Company Name</li>
+    <li>Accurate and complete contact information, including e-mail, web, phone,
+        and address of registered office
+    </li>
+    <li>A 15 to 50 word summary of the company's services which provides some
+        detail about which specific services the company offers for PostgreSQL.
+    </li>
+    <li>Geographic location information</li>
+</ul>
+
+<p>Further, the web site you link to in the listing must somewhere mention
+    PostgreSQL as an offered service or platform. If PostgreSQL is not mentioned
+    anywhere on your website, then your listing will not be approved.</p>
+
+<p>Also, do not list your company in every single geographic region unless you
+    are a truly worldwide company (e.g. IBM, Akamai). This may be reason to
+    reject your listing.</p>
+
+<p>Other General Rules include:</p>
+
+<ul>
+    <li>All services must be related to PostgreSQL in some direct and obvious
+        way.
+    </li>
+    <li>Link-only listings (no description or details) will never be
+        acceptable.
+    </li>
+    <li>The WWW admin group of the PostgreSQL project may permanently ban any
+        organization which is the cause of substantiated complaints about
+        accuracy, ethics or legality from members of our community.
+    </li>
+    <li>The WWW team makes no promises about timely approval of announcements.
+        If publication on a specific day is critical to you, you will need to
+        contact the pgsql-www mailing list or a core team member prior to the
+        submission.
+    </li>
+</ul>
+
+<h3>Professional Services and Listings</h3>
+
+<p>For Professional Services, the "provides support and services" check box must
+    be checked. Fill out the following form blanks with the listed information.
+    Incomplete submissions may be rejected.</p>
+
+<ul>
+    <li>URL: your (or your company's) website, it must contain information about
+        the PostgreSQL services you provide.
+    </li>
+    <li>Number of Employees: number of staff you have doing PostgreSQL support
+        or consulting.
+    </li>
+    <li>Hours: the hours support is available. Suggested options include
+        "Business Hours (time zone)", "24x7", "As Arranged"
+    </li>
+    <li>Languages: what human languages you provide support and services in,
+        e.g. Spanish, English, Japanese, etc.
+    </li>
+    <li>Customer Example: if available</li>
+    <li>Experience: detail of your staff's PostgreSQL and related technology
+        experience only.
+    </li>
+</ul>
+
+<h3>Hosting Listings</h3>
+
+<p>If you offer web hosting for PostgreSQL applications, please check the
+    "Provides hosting of PostgreSQL databases"</p>
+
+<p>Supported Interfaces should detail what programming languages (e.g. Perl,
+    Java, Ruby, etc.) and/or what database applications (e.g. Drupal, xTuple,
+    OpenACS, etc.) you specifically have support for. Also include any notes in
+    this space about limitations or special features of your PostgreSQL
+    hosting.</p>
+
+<p>Your web site must specifically list PostgreSQL as a supported hosted
+    application if you list the other applications which you support on your
+    hosting platform.</p>
+
+<h3>Removal</h3>
+
+<p>Professional Services and Hosting listings are offered purely and entirely
+    for the benefit of our not-for-profit member community. Postgresql.org is
+    not an advertising service or publication. If our admins feel that your
+    listing is inconsistent with the good of our community, your listing may be
+    removed for any reason, or no reason.</p>
+
+<p>Specific reasons which are likely to get your listing removed include:</p>
+
+<ul>
+    <li>Community member complaints about the quality of your services</li>
+    <li>Community member reports that your company cannot be contacted</li>
+    <li>Failure to list PostgreSQL services or hosting as available on your web
+        site
+    </li>
+    <li>Use of postgresql.org, its mailing lists, or associated forums and
+        communications for aggressive or cold-call sales campaigns
+    </li>
+</ul>
+
+<p>If your listing is removed, the admins will usually notify you of the reason
+    for removal, though such notice is not guaranteed.</p>
+
+{%endblock%}
diff --git a/templates/pages/about/policies/sponsoring.html b/templates/pages/about/policies/sponsoring.html
new file mode 100644
index 0000000..c360aa0
--- /dev/null
+++ b/templates/pages/about/policies/sponsoring.html
@@ -0,0 +1,63 @@
+{%extends "base/page.html"%}
+{%block title%}Sponsoring{%endblock%}
+{%block contents%}
+
+<h1>Sponsoring <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: June 1, 2018</em></p>
+
+<h2>Sponsorship levels</h2>
+
+<p>There are two levels of PostgreSQL Sponsors:</p>
+
+<ul>
+    <li><b>Minor sponsors</b> indicate organizations which have provided notable
+        contributions in recent years.
+    </li>
+    <li><b>Major sponsors</b> indicate organizations that have provided
+        significant and/or sustaining contributions over many years.
+    </li>
+</ul>
+
+<p>Contributions to the PostgreSQL Project that may be considered by the
+    committee include, but are not limited to:</p>
+
+<ul>
+    <li>Funding of feature development, review, documentation, advocacy,
+        administration, or other recognized needs of the project.
+    </li>
+    <li>Employing staff to work on the PostgreSQL Project.</li>
+    <li>Providing servers and/or hosting for testing or project
+        infrastructure.
+    </li>
+    <li>Contributing to recognized PostgreSQL Open Source "ecosystem" projects
+        such as drivers, extensions, graphical tools, and advocacy.
+    </li>
+</ul>
+
+<p>Sponsorship for PostgreSQL events will not be considered in determining
+    PostgreSQL sponsorship levels.</p>
+
+<p>All sponsorship recognition is at the discretion of the Sponsor Committee,
+    who will decide on the status of each sponsor or potential sponsor on an
+    individual basis. In exceptional circumstances, a contributor may be
+    recognised at a sponsorship level for outstanding contributions over a
+    period of time lower than the above stated durations. The decision of the
+    committee is final.</p>
+
+<h2>Sponsorship Committee</h2>
+
+<p>Using the guidelines above, sponsorship is ultimately determined by the
+    Sponsorship committee. The current members are:</p>
+
+<ul>
+    <li>Tatsuo Ishii</li>
+    <li>Jonathan S. Katz</li>
+    <li>Dave Page</li>
+    <li>Robert Treat</li>
+</ul>
+
+<p>The current method of choosing who qualifies as a sponsor is via simple
+    majority vote of those in the committee.</p>
+
+{%endblock%}
diff --git a/templates/pages/about/policies/trademark_policy.html b/templates/pages/about/policies/trademark_policy.html
new file mode 100644
index 0000000..96307b6
--- /dev/null
+++ b/templates/pages/about/policies/trademark_policy.html
@@ -0,0 +1,84 @@
+{%extends "base/page.html"%}
+{%block title%}Trademark Policy{%endblock%}
+{%block contents%}
+
+<h1>Trademark Policy <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: August 28, 2018</em></p>
+
+<h2>Policy</h2>
+
+<p>The PostgreSQL <a href="https://wiki.postgresql.org/wiki/Logo">elephant
+    logo</a> (Slonik) and the names "PostgreSQL" and "Postgres" are registered
+    trademarks of the <a href="http://www.postgres.ca/">PostgreSQL Community
+        Association of Canada</a>. If you wish to use either name or logo in any
+    way, you must comply with this policy.</p>
+
+<ul>
+    <li>The names and logo, or derivatives of them may be used to promote
+        PostgreSQL based products or services.
+    </li>
+    <li>The names and logo, or derivatives of them may be used to promote or
+        serve PostgreSQL or related projects and their communities.
+    </li>
+    <li>You may not state or otherwise lead people to believe, that you
+        represent the PostgreSQL Global Development Group in any way other than
+        as an individual or corporate contributor to the project.
+    </li>
+</ul>
+
+<h2>Examples</h2>
+
+<p>The following are examples of acceptable uses of the logo:</p>
+
+<ul>
+    <li>Inclusion of the name(s) or logo on your website offering PostgreSQL
+        support or consultancy services.
+    </li>
+    <li>Inclusion of the name(s) or logo on your website from which you offer
+        PostgreSQL-related or PostgreSQL-derived software products.
+    </li>
+    <li>Inclusion of a modified version of the logo on a PostgreSQL user forum
+        that you run.
+    </li>
+    <li>Inclusion of the name(s) or logo in your software or documentation to
+        indicate that it runs on or with PostgreSQL.
+    </li>
+    <li>Use of the name(s) or logo on websites, publications or merchandise,
+        modified or unmodified, for PostgreSQL user groups, events, or
+        non-profit organizations which support PostgreSQL.
+    </li>
+    <li>Use of the name(s) or logo to advertise PostgreSQL-related content in a
+        public event.
+    </li>
+    <li>Use of the name(s) or logo in news articles or blogs which reference the
+        PostgreSQL Project or database system.
+    </li>
+</ul>
+
+<h2>Unacceptable use</h2>
+
+<p>The following are example of uses of the logo which are NOT acceptable:</p>
+
+<ul>
+    <li>Use of the name(s) or logo in a software product that is unrelated to
+        PostgreSQL and does not run on it, or work with it.
+    </li>
+    <li>Use of the name(s) or logo to promote a product that directly competes
+        with PostgreSQL but is otherwise unrelated.
+    </li>
+    <li>Use of the name(s) or logo for a club or function that is unrelated to
+        PostgreSQL.
+    </li>
+</ul>
+
+<h2>Contact</h2>
+
+<p>The PostgreSQL Community Association of Canada has designated the PostgreSQL
+    Core Team to be its authoritative agent in most matters regarding trademark
+    usage. If you have any questions about this policy, or its interpretation,
+    please email them at
+    <a href="mailto:pgsql-core@postgresql.org">pgsql-core@postgresql.org</a>.
+</p>
+
+{%endblock%}
diff --git a/templates/pages/about/policies/twitter_policy.html b/templates/pages/about/policies/twitter_policy.html
new file mode 100644
index 0000000..b17c2e4
--- /dev/null
+++ b/templates/pages/about/policies/twitter_policy.html
@@ -0,0 +1,88 @@
+{%extends "base/page.html"%}
+{%block title%}@postgresql Twitter Account Policy{%endblock%}
+{%block contents%}
+
+<h1>@postgresql Twitter Account Policy <i class="fas fa-gavel"></i></h1>
+
+<p><em>Last updated: January 19, 2018</em></p>
+
+<p>This policy applies to the manual use of the @postgresql Twitter account.</p>
+
+<ul>
+    <li>Tweets are allowed which relate to approved News & Events as defined in
+        the News and Events Approval Policies (a.k.a. the -announce policy),
+        provided that the tweets are:
+        <ul>
+            <li>Of a reasonable frequency (as defined by the moderators, with
+                the following guidelines):
+            </li>
+            <li>Tweets/Re-tweets about Core and "Family" News are not
+                frequency-limited.
+            </li>
+            <li>Tweets/Re-tweets about Proprietary & External OSS Project News
+                should not be more than weekly.
+            </li>
+            <li>Tweets/Re-tweets about the activity of a PostgreSQL recognized
+                community conference or event should not be more than daily.
+            </li>
+            <li>Tweets/Re-tweets about the activity of a particular Open Source
+                & Database Conference or Event should not be more than weekly.
+            </li>
+            <li>Tweets/Re-tweets about finding information contained on a
+                website within the PostgreSQL infrastructure are not frequency
+                limited.
+            </li>
+        </ul>
+    </li>
+    <li>Are not commercial in nature (Tweets about a given organization
+        sponsoring a conference are ok, tweets which are attempting to solicit
+        sponsorship for an event are not).
+    </li>
+</ul>
+
+<p>In addition to approved News & Events, these kinds of Events may also be
+    tweet'd about, following the same guidelines set forth above:</p>
+
+<ul>
+    <li>Local PostgreSQL User Group (PUG) meetings and related efforts to
+        establish PUGs. PUGs are encouraged to have their own Twitter handle
+        which @postgresql will retweets appropriate tweets from.
+    </li>
+    <li>PostgreSQL Weekly news (weekly tweet highlighting the -announce post).
+    </li>
+    <li>Tweets/Re-tweets are also allowed for acceptable blog posts, media
+        coverage, and tweets about PostgreSQL, provided these are not commercial
+        in nature, using the same guidelines as set forth in the Planet
+        PostgreSQL policy.
+    </li>
+</ul>
+
+<p>Replies to mentions are also allowed when and if appropriate, per these
+    guidelines:</p>
+
+<ul>
+    <li>Acceptable:
+        <ul>
+            <li>Answering a PostgreSQL-specific question to provide help.</li>
+            <li>Providing a helpful suggestion or comment.</li>
+            <li>Professional discussion regarding specific technical aspects of
+                PostgreSQL as compared to other products or projects.
+            </li>
+        </ul>
+    </li>
+
+    <li>Not acceptable:
+        <ul>
+            <li>Off-topic tweets which are not related to PostgreSQL.</li>
+            <li>Degrading or attacking other products, projects, or
+                individuals.
+            </li>
+            <li>Unprofessional behavior of any kind.</li>
+        </ul>
+    </li>
+</ul>
+
+<p>Tweets should follow the same guidelines as one would use when posting to the
+    project mailing lists.</p>
+
+{%endblock%}
